/**
  *******************************************************************************************************
  * @file    ads1232.c 
  * @author  Erisson Siqueira  
  * @brief   Test Version
  *******************************************************************************************************
 */
	
/* Includes --------------------------------------------------------------------------------------------*/
#include "stm32f1xx_hal.h"
#include "ads1232.h"

#include <stdio.h>
#include <math.h>
#include <string.h>
#include <stdlib.h>	


/* Defines ---------------------------------------------------------------------------------------------*/

/* Variables -------------------------------------------------------------------------------------------*/
int 			Value=0;
int 			Num=0;
int 			Sum=0;
int 			Buffer[MAX_BUFFER];

/* Functions -------------------------------------------------------------------------------------------*/
// START
void Start(void)
{
		SCLK(0);
		PDOWN(1);																		// Turn on module
	
		Delay_us(20);																// Wait 20us
			
		A0(0);																			// Channel to read
		
		/********** GAIN_128 *********/	
		GAIN_1(1);	
		GAIN_0(1);		
	
		/********** 80_SPS ***********/
		SPEED(1);
	
		Delay_us(20);																// Wait 20us
	
		while(DOUT_READ_BIT);												// Wait for data ready	
}

// CALIB
void Calib(void)
{		
		
		while(DOUT_READ_BIT)
		{ 
				SCLK(0);																
				SCLK(1);
				Delay_us(1);														// Wait 1us
				SCLK(0);				
		}
		
		for (char count=1;count<=4;count++) 
		{
				Delay_ms(100);													// Wait 100ms
				Read();
		}			
		
		while(DOUT_READ_BIT);												// Wait for data ready
		
		for(char count=0;count<=25;count++)					// 25 Clocks
		{
				SCLK(0);
				SCLK(1);
				Delay_us(1);														// Wait 1us
				SCLK(0);	
		}
		
		Delay_ms(1000);															// Wait 1s
}

// READ
void Read(void)
{		
		unsigned int data	=	0;
					
		while(DOUT_READ_BIT);												// Wait for data ready
				
		Num++;																			// Counter

		for (char count=0; count<24; count++)				// 24 Clocks
		{					
			data = data << 1;													// Shift Left
			
			/*** Clock Falling Edge *****/
			SCLK(1);																	
			SCLK(0);
						
			if(DOUT_READ_BIT)
					data = data | 0x000001;								// Set 1	
			else				
					data = data & 0xFFFFFE;								// Set 0
		}
		
		/******** 25th clock *********/
		SCLK(1);
		SCLK(0);
				
		/****** Twos complement ******/
		if ((data & 0x00800000) > 0)
		{  
			Value = data | 0xFF000000;  						// 32 Bits Negative Form
		}
		else
		{  
			Value = data & 0x00FFFFFF;  						// 32 Bits Positive Form
		} 
		
		for (int i=0; i<MAX_BUFFER-1; i++)
		{
				Buffer[i]=Buffer[i+1];								// Rotate Buffer
		}
		Buffer[MAX_BUFFER-1]=Value;								// Storage Value
				
		Sum+=Value;																// Sum Values	
}


// DELAY US
void Delay_us (int delay)
{
	float Fclk_Hz = 72000000;
	
	float temp;
	long temp1;

		temp = (1/Fclk_Hz) ;
		temp1 = ((delay / temp)/6000000);
		for (;temp1>0;temp1--);
}

// DELAY MS
void 	Delay_ms (int delay)
{
	float Fclk_Hz = 72000000;
	
	float temp;
	long temp1;

		temp = (1/Fclk_Hz) ;
		temp1 = ((delay / temp)/8000);
		for (temp1=temp1 ;temp1>0;temp1--);
}


